==> kubernetes-client-5.0.0-sources.jar: io/fabric8/kubernetes/client/handlers/core/v1/SecretHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.core.v1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.core.v1.SecretOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class SecretHandler implements ResourceHandler<Secret, SecretBuilder> {

  @Override
  public String getKind() {
    return Secret.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "v1";
      }

  @Override
  public Secret create(OkHttpClient client, Config config, String namespace, Secret item) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public Secret replace(OkHttpClient client, Config config, String namespace, Secret item) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public Secret reload(OkHttpClient client, Config config, String namespace, Secret item) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public SecretBuilder edit(Secret item) {
    return new SecretBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, Secret item) {
    return new SecretOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Secret item, Watcher<Secret> watcher) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Secret item, String resourceVersion, Watcher<Secret> watcher) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Secret item, ListOptions options, Watcher<Secret> watcher) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public Secret waitUntilReady(OkHttpClient client, Config config, String namespace, Secret item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Secret waitUntilCondition(OkHttpClient client, Config config, String namespace, Secret item, Predicate<Secret> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-5.2.1-sources.jar: io/fabric8/kubernetes/client/handlers/core/v1/SecretHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.core.v1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.core.v1.SecretOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class SecretHandler implements ResourceHandler<Secret, SecretBuilder> {

  @Override
  public String getKind() {
    return Secret.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "v1";
      }

  @Override
  public Secret create(OkHttpClient client, Config config, String namespace, Secret item, boolean dryRun) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public Secret replace(OkHttpClient client, Config config, String namespace, Secret item, boolean dryRun) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public Secret reload(OkHttpClient client, Config config, String namespace, Secret item) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public SecretBuilder edit(Secret item) {
    return new SecretBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, Secret item, boolean dryRun) {
    return new SecretOperationsImpl(client, config, namespace).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

@Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Secret item, Watcher<Secret> watcher) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Secret item, String resourceVersion, Watcher<Secret> watcher) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Secret item, ListOptions options, Watcher<Secret> watcher) {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public Secret waitUntilReady(OkHttpClient client, Config config, String namespace, Secret item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Secret waitUntilCondition(OkHttpClient client, Config config, String namespace, Secret item, Predicate<Secret> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new SecretOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
